@@ -104,7 +104,7 @@ def neuroCombat(dat,
     # create dictionary that stores batch info
     (batch_levels, sample_per_batch) = np.unique(covars[:,batch_col],return_counts=True)
     info_dict = {
-        'batch_levels': batch_levels.astype('int'),
+        'batch_levels': batch_levels,
         'ref_level': ref_level,
         'n_batch': len(batch_levels),
         'n_sample': int(covars.shape[0]),
@@ -226,6 +226,8 @@ def standardize_across_features(X, design, info_dict):
     else:
         var_pooled = np.dot(((X - np.dot(design, B_hat).T)**2), np.ones((n_sample, 1)) / float(n_sample))
 
+    var_pooled[var_pooled==0] = np.median(var_pooled!=0)
+
     tmp = np.array(design.copy())
     tmp[:,:n_batch] = 0
     stand_mean  += np.dot(tmp, B_hat).T
